# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'manuskript/ui/mainWindow.ui'
#
# Created by: PyQt5 UI code generator 5.5.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1112, 808)
        MainWindow.setWindowTitle("Manuskript")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_2.setContentsMargins(0, 1, 0, 0)
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.stack = QtWidgets.QStackedWidget(self.centralwidget)
        self.stack.setObjectName("stack")
        self.welcomePage = QtWidgets.QWidget()
        self.welcomePage.setObjectName("welcomePage")
        self.gridLayout = QtWidgets.QGridLayout(self.welcomePage)
        self.gridLayout.setObjectName("gridLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 1, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 1, 2, 1, 1)
        self.welcome = welcome(self.welcomePage)
        self.welcome.setMinimumSize(QtCore.QSize(200, 200))
        self.welcome.setObjectName("welcome")
        self.gridLayout.addWidget(self.welcome, 1, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem2, 0, 1, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem3, 2, 1, 1, 1)
        self.stack.addWidget(self.welcomePage)
        self.page_4 = QtWidgets.QWidget()
        self.page_4.setObjectName("page_4")
        self.horizontalLayout_33 = QtWidgets.QHBoxLayout(self.page_4)
        self.horizontalLayout_33.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_33.setObjectName("horizontalLayout_33")
        self.tabMain = QtWidgets.QTabWidget(self.page_4)
        self.tabMain.setTabPosition(QtWidgets.QTabWidget.North)
        self.tabMain.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.tabMain.setDocumentMode(True)
        self.tabMain.setObjectName("tabMain")
        self.lytTabOverview = QtWidgets.QWidget()
        self.lytTabOverview.setObjectName("lytTabOverview")
        self.verticalLayout_23 = QtWidgets.QVBoxLayout(self.lytTabOverview)
        self.verticalLayout_23.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_23.setObjectName("verticalLayout_23")
        self.horizontalLayout_26 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_26.setObjectName("horizontalLayout_26")
        self.grpBookInfos = QtWidgets.QGroupBox(self.lytTabOverview)
        self.grpBookInfos.setObjectName("grpBookInfos")
        self.formLayout_3 = QtWidgets.QFormLayout(self.grpBookInfos)
        self.formLayout_3.setContentsMargins(6, 6, 6, -1)
        self.formLayout_3.setObjectName("formLayout_3")
        self.label_10 = QtWidgets.QLabel(self.grpBookInfos)
        self.label_10.setObjectName("label_10")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_10)
        self.txtGeneralTitle = lineEditView(self.grpBookInfos)
        self.txtGeneralTitle.setObjectName("txtGeneralTitle")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.txtGeneralTitle)
        self.label_11 = QtWidgets.QLabel(self.grpBookInfos)
        self.label_11.setObjectName("label_11")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_11)
        self.txtGeneralSubtitle = lineEditView(self.grpBookInfos)
        self.txtGeneralSubtitle.setObjectName("txtGeneralSubtitle")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.txtGeneralSubtitle)
        self.label_12 = QtWidgets.QLabel(self.grpBookInfos)
        self.label_12.setObjectName("label_12")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_12)
        self.txtGeneralSerie = lineEditView(self.grpBookInfos)
        self.txtGeneralSerie.setObjectName("txtGeneralSerie")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.txtGeneralSerie)
        self.label_13 = QtWidgets.QLabel(self.grpBookInfos)
        self.label_13.setObjectName("label_13")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_13)
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        self.txtGeneralVolume = lineEditView(self.grpBookInfos)
        self.txtGeneralVolume.setObjectName("txtGeneralVolume")
        self.horizontalLayout_25.addWidget(self.txtGeneralVolume)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_25.addItem(spacerItem4)
        self.formLayout_3.setLayout(3, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_25)
        self.label_14 = QtWidgets.QLabel(self.grpBookInfos)
        self.label_14.setObjectName("label_14")
        self.formLayout_3.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_14)
        self.txtGeneralGenre = lineEditView(self.grpBookInfos)
        self.txtGeneralGenre.setObjectName("txtGeneralGenre")
        self.formLayout_3.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.txtGeneralGenre)
        self.label_16 = QtWidgets.QLabel(self.grpBookInfos)
        self.label_16.setObjectName("label_16")
        self.formLayout_3.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_16)
        self.txtGeneralLicense = lineEditView(self.grpBookInfos)
        self.txtGeneralLicense.setObjectName("txtGeneralLicense")
        self.formLayout_3.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.txtGeneralLicense)
        self.horizontalLayout_26.addWidget(self.grpBookInfos)
        self.grpAuthor = QtWidgets.QGroupBox(self.lytTabOverview)
        self.grpAuthor.setObjectName("grpAuthor")
        self.formLayout_4 = QtWidgets.QFormLayout(self.grpAuthor)
        self.formLayout_4.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout_4.setContentsMargins(6, 6, 6, -1)
        self.formLayout_4.setObjectName("formLayout_4")
        self.label_15 = QtWidgets.QLabel(self.grpAuthor)
        self.label_15.setObjectName("label_15")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_15)
        self.txtGeneralAuthor = lineEditView(self.grpAuthor)
        self.txtGeneralAuthor.setObjectName("txtGeneralAuthor")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.txtGeneralAuthor)
        self.label_19 = QtWidgets.QLabel(self.grpAuthor)
        self.label_19.setObjectName("label_19")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_19)
        self.txtGeneralEmail = lineEditView(self.grpAuthor)
        self.txtGeneralEmail.setObjectName("txtGeneralEmail")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.txtGeneralEmail)
        self.horizontalLayout_26.addWidget(self.grpAuthor)
        self.verticalLayout_23.addLayout(self.horizontalLayout_26)
        self.tabMain.addTab(self.lytTabOverview, "")
        self.lytTabSummary = QtWidgets.QWidget()
        self.lytTabSummary.setObjectName("lytTabSummary")
        self.verticalLayout_24 = QtWidgets.QVBoxLayout(self.lytTabSummary)
        self.verticalLayout_24.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_24.setObjectName("verticalLayout_24")
        self.formLayout_5 = QtWidgets.QFormLayout()
        self.formLayout_5.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTop|QtCore.Qt.AlignTrailing)
        self.formLayout_5.setObjectName("formLayout_5")
        self.label_9 = QtWidgets.QLabel(self.lytTabSummary)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_9)
        self.label_29 = QtWidgets.QLabel(self.lytTabSummary)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_29.setFont(font)
        self.label_29.setObjectName("label_29")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_29)
        self.lytSummary = QtWidgets.QVBoxLayout()
        self.lytSummary.setObjectName("lytSummary")
        self.cmbSummary = QtWidgets.QComboBox(self.lytTabSummary)
        self.cmbSummary.setObjectName("cmbSummary")
        self.cmbSummary.addItem("")
        self.cmbSummary.addItem("")
        self.cmbSummary.addItem("")
        self.cmbSummary.addItem("")
        self.lytSummary.addWidget(self.cmbSummary)
        self.formLayout_5.setLayout(1, QtWidgets.QFormLayout.FieldRole, self.lytSummary)
        self.tabSummary = QtWidgets.QStackedWidget(self.lytTabSummary)
        self.tabSummary.setObjectName("tabSummary")
        self.tabSummaryPage1 = QtWidgets.QWidget()
        self.tabSummaryPage1.setObjectName("tabSummaryPage1")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.tabSummaryPage1)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.label = QtWidgets.QLabel(self.tabSummaryPage1)
        self.label.setObjectName("label")
        self.verticalLayout_5.addWidget(self.label)
        self.txtSummarySentence = MDEditCompleter(self.tabSummaryPage1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtSummarySentence.sizePolicy().hasHeightForWidth())
        self.txtSummarySentence.setSizePolicy(sizePolicy)
        self.txtSummarySentence.setObjectName("txtSummarySentence")
        self.verticalLayout_5.addWidget(self.txtSummarySentence)
        self.lblSummaryWCSentence = QtWidgets.QLabel(self.tabSummaryPage1)
        self.lblSummaryWCSentence.setText("")
        self.lblSummaryWCSentence.setObjectName("lblSummaryWCSentence")
        self.verticalLayout_5.addWidget(self.lblSummaryWCSentence)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem5)
        self.tabSummary.addWidget(self.tabSummaryPage1)
        self.tabSummaryPage2 = QtWidgets.QWidget()
        self.tabSummaryPage2.setObjectName("tabSummaryPage2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.tabSummaryPage2)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_21 = QtWidgets.QLabel(self.tabSummaryPage2)
        self.label_21.setObjectName("label_21")
        self.verticalLayout.addWidget(self.label_21)
        self.txtSummarySentence_2 = MDEditCompleter(self.tabSummaryPage2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtSummarySentence_2.sizePolicy().hasHeightForWidth())
        self.txtSummarySentence_2.setSizePolicy(sizePolicy)
        self.txtSummarySentence_2.setReadOnly(True)
        self.txtSummarySentence_2.setObjectName("txtSummarySentence_2")
        self.verticalLayout.addWidget(self.txtSummarySentence_2)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem6)
        self.horizontalLayout_4.addLayout(self.verticalLayout)
        self.line = QtWidgets.QFrame(self.tabSummaryPage2)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_4.addWidget(self.line)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.tabSummaryPage2)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_2.addWidget(self.label_2)
        self.txtSummaryPara = MDEditCompleter(self.tabSummaryPage2)
        self.txtSummaryPara.setObjectName("txtSummaryPara")
        self.verticalLayout_2.addWidget(self.txtSummaryPara)
        self.lblSummaryWCPara = QtWidgets.QLabel(self.tabSummaryPage2)
        self.lblSummaryWCPara.setText("")
        self.lblSummaryWCPara.setObjectName("lblSummaryWCPara")
        self.verticalLayout_2.addWidget(self.lblSummaryWCPara)
        spacerItem7 = QtWidgets.QSpacerItem(20, 264, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem7)
        self.horizontalLayout_4.addLayout(self.verticalLayout_2)
        self.tabSummary.addWidget(self.tabSummaryPage2)
        self.tabSummaryPage3 = QtWidgets.QWidget()
        self.tabSummaryPage3.setObjectName("tabSummaryPage3")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.tabSummaryPage3)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.label_22 = QtWidgets.QLabel(self.tabSummaryPage3)
        self.label_22.setObjectName("label_22")
        self.verticalLayout_6.addWidget(self.label_22)
        self.txtSummaryPara_2 = MDEditCompleter(self.tabSummaryPage3)
        self.txtSummaryPara_2.setReadOnly(True)
        self.txtSummaryPara_2.setObjectName("txtSummaryPara_2")
        self.verticalLayout_6.addWidget(self.txtSummaryPara_2)
        spacerItem8 = QtWidgets.QSpacerItem(20, 264, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem8)
        self.horizontalLayout_7.addLayout(self.verticalLayout_6)
        self.line_2 = QtWidgets.QFrame(self.tabSummaryPage3)
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout_7.addWidget(self.line_2)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label_17 = QtWidgets.QLabel(self.tabSummaryPage3)
        self.label_17.setObjectName("label_17")
        self.verticalLayout_3.addWidget(self.label_17)
        self.txtSummaryPage = MDEditCompleter(self.tabSummaryPage3)
        self.txtSummaryPage.setObjectName("txtSummaryPage")
        self.verticalLayout_3.addWidget(self.txtSummaryPage)
        self.lblSummaryWCPage = QtWidgets.QLabel(self.tabSummaryPage3)
        self.lblSummaryWCPage.setText("")
        self.lblSummaryWCPage.setObjectName("lblSummaryWCPage")
        self.verticalLayout_3.addWidget(self.lblSummaryWCPage)
        self.horizontalLayout_7.addLayout(self.verticalLayout_3)
        self.tabSummary.addWidget(self.tabSummaryPage3)
        self.tabSummaryPage4 = QtWidgets.QWidget()
        self.tabSummaryPage4.setObjectName("tabSummaryPage4")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.tabSummaryPage4)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.label_23 = QtWidgets.QLabel(self.tabSummaryPage4)
        self.label_23.setObjectName("label_23")
        self.verticalLayout_7.addWidget(self.label_23)
        self.txtSummaryPage_2 = MDEditCompleter(self.tabSummaryPage4)
        self.txtSummaryPage_2.setReadOnly(True)
        self.txtSummaryPage_2.setObjectName("txtSummaryPage_2")
        self.verticalLayout_7.addWidget(self.txtSummaryPage_2)
        self.horizontalLayout_8.addLayout(self.verticalLayout_7)
        self.line_3 = QtWidgets.QFrame(self.tabSummaryPage4)
        self.line_3.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.horizontalLayout_8.addWidget(self.line_3)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.label_20 = QtWidgets.QLabel(self.tabSummaryPage4)
        self.label_20.setObjectName("label_20")
        self.verticalLayout_4.addWidget(self.label_20)
        self.txtSummaryFull = MDEditCompleter(self.tabSummaryPage4)
        self.txtSummaryFull.setObjectName("txtSummaryFull")
        self.verticalLayout_4.addWidget(self.txtSummaryFull)
        self.lblSummaryWCFull = QtWidgets.QLabel(self.tabSummaryPage4)
        self.lblSummaryWCFull.setText("")
        self.lblSummaryWCFull.setObjectName("lblSummaryWCFull")
        self.verticalLayout_4.addWidget(self.lblSummaryWCFull)
        self.horizontalLayout_8.addLayout(self.verticalLayout_4)
        self.tabSummary.addWidget(self.tabSummaryPage4)
        self.formLayout_5.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.tabSummary)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem9)
        self.btnStepThree = QtWidgets.QPushButton(self.lytTabSummary)
        icon = QtGui.QIcon.fromTheme("go-next")
        self.btnStepThree.setIcon(icon)
        self.btnStepThree.setObjectName("btnStepThree")
        self.horizontalLayout_5.addWidget(self.btnStepThree)
        self.btnStepTwo = QtWidgets.QPushButton(self.lytTabSummary)
        icon = QtGui.QIcon.fromTheme("go-next")
        self.btnStepTwo.setIcon(icon)
        self.btnStepTwo.setObjectName("btnStepTwo")
        self.horizontalLayout_5.addWidget(self.btnStepTwo)
        self.btnStepFive = QtWidgets.QPushButton(self.lytTabSummary)
        icon = QtGui.QIcon.fromTheme("go-next")
        self.btnStepFive.setIcon(icon)
        self.btnStepFive.setObjectName("btnStepFive")
        self.horizontalLayout_5.addWidget(self.btnStepFive)
        self.btnStepSeven = QtWidgets.QPushButton(self.lytTabSummary)
        icon = QtGui.QIcon.fromTheme("go-next")
        self.btnStepSeven.setIcon(icon)
        self.btnStepSeven.setObjectName("btnStepSeven")
        self.horizontalLayout_5.addWidget(self.btnStepSeven)
        self.formLayout_5.setLayout(3, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_5)
        self.lytSituation = QtWidgets.QVBoxLayout()
        self.lytSituation.setObjectName("lytSituation")
        self.txtSummarySituation = lineEditView(self.lytTabSummary)
        self.txtSummarySituation.setObjectName("txtSummarySituation")
        self.lytSituation.addWidget(self.txtSummarySituation)
        self.formLayout_5.setLayout(0, QtWidgets.QFormLayout.FieldRole, self.lytSituation)
        self.verticalLayout_24.addLayout(self.formLayout_5)
        self.tabMain.addTab(self.lytTabSummary, "")
        self.lytTabPersos = QtWidgets.QWidget()
        self.lytTabPersos.setObjectName("lytTabPersos")
        self.verticalLayout_25 = QtWidgets.QVBoxLayout(self.lytTabPersos)
        self.verticalLayout_25.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_25.setObjectName("verticalLayout_25")
        self.splitterPersos = QtWidgets.QSplitter(self.lytTabPersos)
        self.splitterPersos.setOrientation(QtCore.Qt.Horizontal)
        self.splitterPersos.setChildrenCollapsible(False)
        self.splitterPersos.setObjectName("splitterPersos")
        self.groupBox = QtWidgets.QGroupBox(self.splitterPersos)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.lstCharacters = characterTreeView(self.groupBox)
        self.lstCharacters.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.lstCharacters.setDragEnabled(True)
        self.lstCharacters.setObjectName("lstCharacters")
        self.lstCharacters.headerItem().setText(0, "1")
        self.verticalLayout_8.addWidget(self.lstCharacters)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.btnAddPerso = QtWidgets.QPushButton(self.groupBox)
        self.btnAddPerso.setText("")
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnAddPerso.setIcon(icon)
        self.btnAddPerso.setFlat(True)
        self.btnAddPerso.setObjectName("btnAddPerso")
        self.horizontalLayout_14.addWidget(self.btnAddPerso)
        self.btnRmPerso = QtWidgets.QPushButton(self.groupBox)
        self.btnRmPerso.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnRmPerso.setIcon(icon)
        self.btnRmPerso.setFlat(True)
        self.btnRmPerso.setObjectName("btnRmPerso")
        self.horizontalLayout_14.addWidget(self.btnRmPerso)
        self.txtPersosFilter = QtWidgets.QLineEdit(self.groupBox)
        self.txtPersosFilter.setClearButtonEnabled(True)
        self.txtPersosFilter.setObjectName("txtPersosFilter")
        self.horizontalLayout_14.addWidget(self.txtPersosFilter)
        self.verticalLayout_8.addLayout(self.horizontalLayout_14)
        self.tabPersos = QtWidgets.QTabWidget(self.splitterPersos)
        self.tabPersos.setObjectName("tabPersos")
        self.info = QtWidgets.QWidget()
        self.info.setObjectName("info")
        self.verticalLayout_20 = QtWidgets.QVBoxLayout(self.info)
        self.verticalLayout_20.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_20.setSpacing(0)
        self.verticalLayout_20.setObjectName("verticalLayout_20")
        self.scrollAreaPersoInfos = QtWidgets.QScrollArea(self.info)
        self.scrollAreaPersoInfos.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.scrollAreaPersoInfos.setLineWidth(0)
        self.scrollAreaPersoInfos.setWidgetResizable(True)
        self.scrollAreaPersoInfos.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.scrollAreaPersoInfos.setObjectName("scrollAreaPersoInfos")
        self.scrollAreaPersoInfosWidget = QtWidgets.QWidget()
        self.scrollAreaPersoInfosWidget.setGeometry(QtCore.QRect(0, 0, 204, 606))
        self.scrollAreaPersoInfosWidget.setObjectName("scrollAreaPersoInfosWidget")
        self.formLayout_8 = QtWidgets.QFormLayout(self.scrollAreaPersoInfosWidget)
        self.formLayout_8.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_8.setObjectName("formLayout_8")
        self.label_4 = QtWidgets.QLabel(self.scrollAreaPersoInfosWidget)
        self.label_4.setObjectName("label_4")
        self.formLayout_8.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.txtPersoMotivation = MDEditCompleter(self.scrollAreaPersoInfosWidget)
        self.txtPersoMotivation.setObjectName("txtPersoMotivation")
        self.formLayout_8.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.txtPersoMotivation)
        self.label_5 = QtWidgets.QLabel(self.scrollAreaPersoInfosWidget)
        self.label_5.setObjectName("label_5")
        self.formLayout_8.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.txtPersoGoal = MDEditCompleter(self.scrollAreaPersoInfosWidget)
        self.txtPersoGoal.setObjectName("txtPersoGoal")
        self.formLayout_8.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.txtPersoGoal)
        self.label_6 = QtWidgets.QLabel(self.scrollAreaPersoInfosWidget)
        self.label_6.setObjectName("label_6")
        self.formLayout_8.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_6)
        self.txtPersoConflict = MDEditCompleter(self.scrollAreaPersoInfosWidget)
        self.txtPersoConflict.setObjectName("txtPersoConflict")
        self.formLayout_8.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.txtPersoConflict)
        self.label_7 = QtWidgets.QLabel(self.scrollAreaPersoInfosWidget)
        self.label_7.setObjectName("label_7")
        self.formLayout_8.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.label_7)
        self.txtPersoEpiphany = MDEditCompleter(self.scrollAreaPersoInfosWidget)
        self.txtPersoEpiphany.setObjectName("txtPersoEpiphany")
        self.formLayout_8.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.txtPersoEpiphany)
        self.label_24 = QtWidgets.QLabel(self.scrollAreaPersoInfosWidget)
        self.label_24.setObjectName("label_24")
        self.formLayout_8.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.label_24)
        self.txtPersoSummarySentence = MDEditCompleter(self.scrollAreaPersoInfosWidget)
        self.txtPersoSummarySentence.setObjectName("txtPersoSummarySentence")
        self.formLayout_8.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.txtPersoSummarySentence)
        self.label_8 = QtWidgets.QLabel(self.scrollAreaPersoInfosWidget)
        self.label_8.setObjectName("label_8")
        self.formLayout_8.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.txtPersoSummaryPara = MDEditCompleter(self.scrollAreaPersoInfosWidget)
        self.txtPersoSummaryPara.setObjectName("txtPersoSummaryPara")
        self.formLayout_8.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.txtPersoSummaryPara)
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_21.addItem(spacerItem10)
        self.btnStepFour = QtWidgets.QPushButton(self.scrollAreaPersoInfosWidget)
        icon = QtGui.QIcon.fromTheme("go-next")
        self.btnStepFour.setIcon(icon)
        self.btnStepFour.setFlat(True)
        self.btnStepFour.setObjectName("btnStepFour")
        self.horizontalLayout_21.addWidget(self.btnStepFour)
        self.formLayout_8.setLayout(10, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_21)
        self.label_18 = QtWidgets.QLabel(self.scrollAreaPersoInfosWidget)
        self.label_18.setObjectName("label_18")
        self.formLayout_8.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_18)
        self.sldPersoImportance = sldImportance(self.scrollAreaPersoInfosWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sldPersoImportance.sizePolicy().hasHeightForWidth())
        self.sldPersoImportance.setSizePolicy(sizePolicy)
        self.sldPersoImportance.setObjectName("sldPersoImportance")
        self.formLayout_8.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.sldPersoImportance)
        self.label_3 = QtWidgets.QLabel(self.scrollAreaPersoInfosWidget)
        self.label_3.setObjectName("label_3")
        self.formLayout_8.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.txtPersoName = lineEditView(self.scrollAreaPersoInfosWidget)
        self.txtPersoName.setObjectName("txtPersoName")
        self.horizontalLayout_3.addWidget(self.txtPersoName)
        self.btnPersoColor = QtWidgets.QPushButton(self.scrollAreaPersoInfosWidget)
        self.btnPersoColor.setText("")
        self.btnPersoColor.setObjectName("btnPersoColor")
        self.horizontalLayout_3.addWidget(self.btnPersoColor)
        self.formLayout_8.setLayout(2, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_3)
        self.scrollAreaPersoInfos.setWidget(self.scrollAreaPersoInfosWidget)
        self.verticalLayout_20.addWidget(self.scrollAreaPersoInfos)
        self.tabPersos.addTab(self.info, "")
        self.tab_11 = QtWidgets.QWidget()
        self.tab_11.setObjectName("tab_11")
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(self.tab_11)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.txtPersoSummaryFull = MDEditCompleter(self.tab_11)
        self.txtPersoSummaryFull.setObjectName("txtPersoSummaryFull")
        self.verticalLayout_17.addWidget(self.txtPersoSummaryFull)
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_22.addItem(spacerItem11)
        self.btnStepSix = QtWidgets.QPushButton(self.tab_11)
        icon = QtGui.QIcon.fromTheme("go-next")
        self.btnStepSix.setIcon(icon)
        self.btnStepSix.setObjectName("btnStepSix")
        self.horizontalLayout_22.addWidget(self.btnStepSix)
        self.verticalLayout_17.addLayout(self.horizontalLayout_22)
        self.tabPersos.addTab(self.tab_11, "")
        self.tab_19 = QtWidgets.QWidget()
        self.tab_19.setObjectName("tab_19")
        self.horizontalLayout_30 = QtWidgets.QHBoxLayout(self.tab_19)
        self.horizontalLayout_30.setObjectName("horizontalLayout_30")
        self.txtPersoNotes = MDEditCompleter(self.tab_19)
        self.txtPersoNotes.setObjectName("txtPersoNotes")
        self.horizontalLayout_30.addWidget(self.txtPersoNotes)
        self.tabPersos.addTab(self.tab_19, "")
        self.tab_12 = QtWidgets.QWidget()
        self.tab_12.setObjectName("tab_12")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.tab_12)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.tblPersoInfos = QtWidgets.QTableView(self.tab_12)
        self.tblPersoInfos.setAlternatingRowColors(True)
        self.tblPersoInfos.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tblPersoInfos.setTextElideMode(QtCore.Qt.ElideNone)
        self.tblPersoInfos.setObjectName("tblPersoInfos")
        self.verticalLayout_9.addWidget(self.tblPersoInfos)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.btnPersoAddInfo = QtWidgets.QPushButton(self.tab_12)
        self.btnPersoAddInfo.setText("")
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnPersoAddInfo.setIcon(icon)
        self.btnPersoAddInfo.setObjectName("btnPersoAddInfo")
        self.horizontalLayout_9.addWidget(self.btnPersoAddInfo)
        self.btnPersoRmInfo = QtWidgets.QPushButton(self.tab_12)
        self.btnPersoRmInfo.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnPersoRmInfo.setIcon(icon)
        self.btnPersoRmInfo.setObjectName("btnPersoRmInfo")
        self.horizontalLayout_9.addWidget(self.btnPersoRmInfo)
        self.lineEdit = QtWidgets.QLineEdit(self.tab_12)
        self.lineEdit.setObjectName("lineEdit")
        self.horizontalLayout_9.addWidget(self.lineEdit)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem12)
        self.btnStepEight = QtWidgets.QPushButton(self.tab_12)
        icon = QtGui.QIcon.fromTheme("go-next")
        self.btnStepEight.setIcon(icon)
        self.btnStepEight.setObjectName("btnStepEight")
        self.horizontalLayout_9.addWidget(self.btnStepEight)
        self.verticalLayout_9.addLayout(self.horizontalLayout_9)
        self.tabPersos.addTab(self.tab_12, "")
        self.verticalLayout_25.addWidget(self.splitterPersos)
        self.tabMain.addTab(self.lytTabPersos, "")
        self.lytTabPlot = QtWidgets.QWidget()
        self.lytTabPlot.setObjectName("lytTabPlot")
        self.verticalLayout_26 = QtWidgets.QVBoxLayout(self.lytTabPlot)
        self.verticalLayout_26.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_26.setObjectName("verticalLayout_26")
        self.splitterPlot = QtWidgets.QSplitter(self.lytTabPlot)
        self.splitterPlot.setOrientation(QtCore.Qt.Horizontal)
        self.splitterPlot.setObjectName("splitterPlot")
        self.groupBox_2 = QtWidgets.QGroupBox(self.splitterPlot)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.lstPlots = plotTreeView(self.groupBox_2)
        self.lstPlots.setObjectName("lstPlots")
        self.lstPlots.headerItem().setText(0, "1")
        self.lstPlots.header().setVisible(False)
        self.verticalLayout_10.addWidget(self.lstPlots)
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.btnAddPlot = QtWidgets.QPushButton(self.groupBox_2)
        self.btnAddPlot.setText("")
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnAddPlot.setIcon(icon)
        self.btnAddPlot.setFlat(True)
        self.btnAddPlot.setObjectName("btnAddPlot")
        self.horizontalLayout_15.addWidget(self.btnAddPlot)
        self.btnRmPlot = QtWidgets.QPushButton(self.groupBox_2)
        self.btnRmPlot.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnRmPlot.setIcon(icon)
        self.btnRmPlot.setFlat(True)
        self.btnRmPlot.setObjectName("btnRmPlot")
        self.horizontalLayout_15.addWidget(self.btnRmPlot)
        self.txtPlotFilter = QtWidgets.QLineEdit(self.groupBox_2)
        self.txtPlotFilter.setClearButtonEnabled(True)
        self.txtPlotFilter.setObjectName("txtPlotFilter")
        self.horizontalLayout_15.addWidget(self.txtPlotFilter)
        self.verticalLayout_10.addLayout(self.horizontalLayout_15)
        self.tabPlot = QtWidgets.QTabWidget(self.splitterPlot)
        self.tabPlot.setDocumentMode(True)
        self.tabPlot.setObjectName("tabPlot")
        self.infos_2 = QtWidgets.QWidget()
        self.infos_2.setObjectName("infos_2")
        self.formLayout_2 = QtWidgets.QFormLayout(self.infos_2)
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_25 = QtWidgets.QLabel(self.infos_2)
        self.label_25.setObjectName("label_25")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_25)
        self.txtPlotName = lineEditView(self.infos_2)
        self.txtPlotName.setObjectName("txtPlotName")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.txtPlotName)
        self.label_31 = QtWidgets.QLabel(self.infos_2)
        self.label_31.setObjectName("label_31")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_31)
        self.label_26 = QtWidgets.QLabel(self.infos_2)
        self.label_26.setObjectName("label_26")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_26)
        self.label_27 = QtWidgets.QLabel(self.infos_2)
        self.label_27.setObjectName("label_27")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_27)
        self.label_28 = QtWidgets.QLabel(self.infos_2)
        self.label_28.setObjectName("label_28")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_28)
        self.verticalLayout_12 = QtWidgets.QVBoxLayout()
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.lstPlotPerso = QtWidgets.QListView(self.infos_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lstPlotPerso.sizePolicy().hasHeightForWidth())
        self.lstPlotPerso.setSizePolicy(sizePolicy)
        self.lstPlotPerso.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.lstPlotPerso.setMovement(QtWidgets.QListView.Static)
        self.lstPlotPerso.setObjectName("lstPlotPerso")
        self.verticalLayout_12.addWidget(self.lstPlotPerso)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        spacerItem13 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_16.addItem(spacerItem13)
        self.btnAddPlotPerso = QtWidgets.QPushButton(self.infos_2)
        self.btnAddPlotPerso.setText("")
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnAddPlotPerso.setIcon(icon)
        self.btnAddPlotPerso.setFlat(True)
        self.btnAddPlotPerso.setObjectName("btnAddPlotPerso")
        self.horizontalLayout_16.addWidget(self.btnAddPlotPerso)
        self.btnRmPlotPerso = QtWidgets.QPushButton(self.infos_2)
        self.btnRmPlotPerso.setEnabled(False)
        self.btnRmPlotPerso.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnRmPlotPerso.setIcon(icon)
        self.btnRmPlotPerso.setFlat(True)
        self.btnRmPlotPerso.setObjectName("btnRmPlotPerso")
        self.horizontalLayout_16.addWidget(self.btnRmPlotPerso)
        self.verticalLayout_12.addLayout(self.horizontalLayout_16)
        self.formLayout_2.setLayout(2, QtWidgets.QFormLayout.FieldRole, self.verticalLayout_12)
        self.sldPlotImportance = sldImportance(self.infos_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sldPlotImportance.sizePolicy().hasHeightForWidth())
        self.sldPlotImportance.setSizePolicy(sizePolicy)
        self.sldPlotImportance.setObjectName("sldPlotImportance")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.sldPlotImportance)
        self.txtPlotDescription = MDEditCompleter(self.infos_2)
        self.txtPlotDescription.setObjectName("txtPlotDescription")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.txtPlotDescription)
        self.txtPlotResult = MDEditCompleter(self.infos_2)
        self.txtPlotResult.setObjectName("txtPlotResult")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.txtPlotResult)
        self.tabPlot.addTab(self.infos_2, "")
        self.tab_15 = QtWidgets.QWidget()
        self.tab_15.setObjectName("tab_15")
        self.verticalLayout_28 = QtWidgets.QVBoxLayout(self.tab_15)
        self.verticalLayout_28.setObjectName("verticalLayout_28")
        self.lstSubPlots = QtWidgets.QTableView(self.tab_15)
        self.lstSubPlots.setDragDropOverwriteMode(False)
        self.lstSubPlots.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self.lstSubPlots.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.lstSubPlots.setShowGrid(False)
        self.lstSubPlots.setObjectName("lstSubPlots")
        self.verticalLayout_28.addWidget(self.lstSubPlots)
        self.grpSubPlotSummary = QtWidgets.QGroupBox(self.tab_15)
        self.grpSubPlotSummary.setObjectName("grpSubPlotSummary")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.grpSubPlotSummary)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.txtSubPlotSummary = MDEditCompleter(self.grpSubPlotSummary)
        self.txtSubPlotSummary.setObjectName("txtSubPlotSummary")
        self.verticalLayout_11.addWidget(self.txtSubPlotSummary)
        self.verticalLayout_28.addWidget(self.grpSubPlotSummary)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.btnAddSubPlot = QtWidgets.QPushButton(self.tab_15)
        self.btnAddSubPlot.setText("")
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnAddSubPlot.setIcon(icon)
        self.btnAddSubPlot.setFlat(True)
        self.btnAddSubPlot.setObjectName("btnAddSubPlot")
        self.horizontalLayout_17.addWidget(self.btnAddSubPlot)
        self.btnRmSubPlot = QtWidgets.QPushButton(self.tab_15)
        self.btnRmSubPlot.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnRmSubPlot.setIcon(icon)
        self.btnRmSubPlot.setFlat(True)
        self.btnRmSubPlot.setObjectName("btnRmSubPlot")
        self.horizontalLayout_17.addWidget(self.btnRmSubPlot)
        spacerItem14 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem14)
        self.btnShowSubPlotSummary = QtWidgets.QPushButton(self.tab_15)
        self.btnShowSubPlotSummary.setText("")
        icon = QtGui.QIcon.fromTheme("text-x-generic")
        self.btnShowSubPlotSummary.setIcon(icon)
        self.btnShowSubPlotSummary.setCheckable(True)
        self.btnShowSubPlotSummary.setChecked(True)
        self.btnShowSubPlotSummary.setFlat(True)
        self.btnShowSubPlotSummary.setObjectName("btnShowSubPlotSummary")
        self.horizontalLayout_17.addWidget(self.btnShowSubPlotSummary)
        self.verticalLayout_28.addLayout(self.horizontalLayout_17)
        self.tabPlot.addTab(self.tab_15, "")
        self.grpPlotSummary = QtWidgets.QGroupBox(self.splitterPlot)
        self.grpPlotSummary.setObjectName("grpPlotSummary")
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(self.grpPlotSummary)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.comboBox_2 = QtWidgets.QComboBox(self.grpPlotSummary)
        self.comboBox_2.setFrame(False)
        self.comboBox_2.setObjectName("comboBox_2")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.comboBox_2.addItem("")
        self.verticalLayout_18.addWidget(self.comboBox_2)
        self.stkPlotSummary = QtWidgets.QStackedWidget(self.grpPlotSummary)
        self.stkPlotSummary.setObjectName("stkPlotSummary")
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.page)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.txtPlotSummaryPara = MDEditCompleter(self.page)
        self.txtPlotSummaryPara.setObjectName("txtPlotSummaryPara")
        self.horizontalLayout_6.addWidget(self.txtPlotSummaryPara)
        self.stkPlotSummary.addWidget(self.page)
        self.page_2 = QtWidgets.QWidget()
        self.page_2.setObjectName("page_2")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.page_2)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.txtPlotSummaryPage = MDEditCompleter(self.page_2)
        self.txtPlotSummaryPage.setObjectName("txtPlotSummaryPage")
        self.horizontalLayout_10.addWidget(self.txtPlotSummaryPage)
        self.stkPlotSummary.addWidget(self.page_2)
        self.page_3 = QtWidgets.QWidget()
        self.page_3.setObjectName("page_3")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.page_3)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.txtPlotSummaryFull = MDEditCompleter(self.page_3)
        self.txtPlotSummaryFull.setObjectName("txtPlotSummaryFull")
        self.horizontalLayout_13.addWidget(self.txtPlotSummaryFull)
        self.stkPlotSummary.addWidget(self.page_3)
        self.verticalLayout_18.addWidget(self.stkPlotSummary)
        self.verticalLayout_26.addWidget(self.splitterPlot)
        self.tabMain.addTab(self.lytTabPlot, "")
        self.lytTabContext = QtWidgets.QWidget()
        self.lytTabContext.setObjectName("lytTabContext")
        self.verticalLayout_33 = QtWidgets.QVBoxLayout(self.lytTabContext)
        self.verticalLayout_33.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_33.setObjectName("verticalLayout_33")
        self.splitterWorld = QtWidgets.QSplitter(self.lytTabContext)
        self.splitterWorld.setOrientation(QtCore.Qt.Horizontal)
        self.splitterWorld.setObjectName("splitterWorld")
        self.frame_3 = QtWidgets.QFrame(self.splitterWorld)
        self.frame_3.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_3.setObjectName("frame_3")
        self.verticalLayout_32 = QtWidgets.QVBoxLayout(self.frame_3)
        self.verticalLayout_32.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_32.setObjectName("verticalLayout_32")
        self.treeWorld = QtWidgets.QTreeView(self.frame_3)
        self.treeWorld.setEditTriggers(QtWidgets.QAbstractItemView.EditKeyPressed)
        self.treeWorld.setDragEnabled(True)
        self.treeWorld.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self.treeWorld.setDefaultDropAction(QtCore.Qt.MoveAction)
        self.treeWorld.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.treeWorld.setIndentation(15)
        self.treeWorld.setRootIsDecorated(False)
        self.treeWorld.setObjectName("treeWorld")
        self.treeWorld.header().setVisible(False)
        self.treeWorld.header().setDefaultSectionSize(0)
        self.verticalLayout_32.addWidget(self.treeWorld)
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.btnAddWorld = QtWidgets.QPushButton(self.frame_3)
        self.btnAddWorld.setText("")
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnAddWorld.setIcon(icon)
        self.btnAddWorld.setFlat(True)
        self.btnAddWorld.setObjectName("btnAddWorld")
        self.horizontalLayout_19.addWidget(self.btnAddWorld)
        self.btnRmWorld = QtWidgets.QPushButton(self.frame_3)
        self.btnRmWorld.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnRmWorld.setIcon(icon)
        self.btnRmWorld.setFlat(True)
        self.btnRmWorld.setObjectName("btnRmWorld")
        self.horizontalLayout_19.addWidget(self.btnRmWorld)
        self.txtWorldFilter = QtWidgets.QLineEdit(self.frame_3)
        self.txtWorldFilter.setClearButtonEnabled(True)
        self.txtWorldFilter.setObjectName("txtWorldFilter")
        self.horizontalLayout_19.addWidget(self.txtWorldFilter)
        self.btnWorldEmptyData = QtWidgets.QPushButton(self.frame_3)
        self.btnWorldEmptyData.setText("")
        icon = QtGui.QIcon.fromTheme("emblem-favorite")
        self.btnWorldEmptyData.setIcon(icon)
        self.btnWorldEmptyData.setFlat(True)
        self.btnWorldEmptyData.setObjectName("btnWorldEmptyData")
        self.horizontalLayout_19.addWidget(self.btnWorldEmptyData)
        self.verticalLayout_32.addLayout(self.horizontalLayout_19)
        self.tabWorld = QtWidgets.QTabWidget(self.splitterWorld)
        self.tabWorld.setDocumentMode(True)
        self.tabWorld.setObjectName("tabWorld")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.formLayout_6 = QtWidgets.QFormLayout(self.tab_3)
        self.formLayout_6.setRowWrapPolicy(QtWidgets.QFormLayout.WrapAllRows)
        self.formLayout_6.setObjectName("formLayout_6")
        self.label_30 = QtWidgets.QLabel(self.tab_3)
        self.label_30.setObjectName("label_30")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_30)
        self.txtWorldName = lineEditView(self.tab_3)
        self.txtWorldName.setObjectName("txtWorldName")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.txtWorldName)
        self.label_32 = QtWidgets.QLabel(self.tab_3)
        self.label_32.setObjectName("label_32")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_32)
        self.txtWorldDescription = MDEditCompleter(self.tab_3)
        self.txtWorldDescription.setObjectName("txtWorldDescription")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.txtWorldDescription)
        self.tabWorld.addTab(self.tab_3, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.formLayout_7 = QtWidgets.QFormLayout(self.tab_4)
        self.formLayout_7.setRowWrapPolicy(QtWidgets.QFormLayout.WrapAllRows)
        self.formLayout_7.setObjectName("formLayout_7")
        self.label_33 = QtWidgets.QLabel(self.tab_4)
        self.label_33.setObjectName("label_33")
        self.formLayout_7.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_33)
        self.txtWorldPassion = MDEditCompleter(self.tab_4)
        self.txtWorldPassion.setObjectName("txtWorldPassion")
        self.formLayout_7.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.txtWorldPassion)
        self.label_34 = QtWidgets.QLabel(self.tab_4)
        self.label_34.setObjectName("label_34")
        self.formLayout_7.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_34)
        self.txtWorldConflict = MDEditCompleter(self.tab_4)
        self.txtWorldConflict.setObjectName("txtWorldConflict")
        self.formLayout_7.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.txtWorldConflict)
        self.tabWorld.addTab(self.tab_4, "")
        self.verticalLayout_33.addWidget(self.splitterWorld)
        self.tabMain.addTab(self.lytTabContext, "")
        self.lytTabOutline = QtWidgets.QWidget()
        self.lytTabOutline.setObjectName("lytTabOutline")
        self.verticalLayout_27 = QtWidgets.QVBoxLayout(self.lytTabOutline)
        self.verticalLayout_27.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_27.setObjectName("verticalLayout_27")
        self.splitterOutlineH = QtWidgets.QSplitter(self.lytTabOutline)
        self.splitterOutlineH.setOrientation(QtCore.Qt.Horizontal)
        self.splitterOutlineH.setObjectName("splitterOutlineH")
        self.lstOutlinePlots = plotTreeView(self.splitterOutlineH)
        self.lstOutlinePlots.setDragEnabled(True)
        self.lstOutlinePlots.setDragDropMode(QtWidgets.QAbstractItemView.DragOnly)
        self.lstOutlinePlots.setObjectName("lstOutlinePlots")
        self.lstOutlinePlots.headerItem().setText(0, "1")
        self.lstOutlinePlots.header().setVisible(False)
        self.layoutWidget = QtWidgets.QWidget(self.splitterOutlineH)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.splitterOutlineV = QtWidgets.QSplitter(self.layoutWidget)
        self.splitterOutlineV.setOrientation(QtCore.Qt.Vertical)
        self.splitterOutlineV.setObjectName("splitterOutlineV")
        self.treeOutlineOutline = outlineView(self.splitterOutlineV)
        self.treeOutlineOutline.setDragEnabled(True)
        self.treeOutlineOutline.setDragDropMode(QtWidgets.QAbstractItemView.DragDrop)
        self.treeOutlineOutline.setDefaultDropAction(QtCore.Qt.MoveAction)
        self.treeOutlineOutline.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.treeOutlineOutline.setObjectName("treeOutlineOutline")
        self.treeOutlineOutline.header().setStretchLastSection(False)
        self.frame = QtWidgets.QFrame(self.splitterOutlineV)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.frame)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.outlineItemEditor = basicItemView(self.frame)
        self.outlineItemEditor.setObjectName("outlineItemEditor")
        self.verticalLayout_13.addWidget(self.outlineItemEditor)
        self.verticalLayout_14.addWidget(self.splitterOutlineV)
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.btnOutlineAddFolder = QtWidgets.QPushButton(self.layoutWidget)
        self.btnOutlineAddFolder.setText("")
        icon = QtGui.QIcon.fromTheme("folder-new")
        self.btnOutlineAddFolder.setIcon(icon)
        self.btnOutlineAddFolder.setFlat(True)
        self.btnOutlineAddFolder.setObjectName("btnOutlineAddFolder")
        self.horizontalLayout_18.addWidget(self.btnOutlineAddFolder)
        self.btnOutlineAddText = QtWidgets.QPushButton(self.layoutWidget)
        self.btnOutlineAddText.setText("")
        icon = QtGui.QIcon.fromTheme("document-new")
        self.btnOutlineAddText.setIcon(icon)
        self.btnOutlineAddText.setFlat(True)
        self.btnOutlineAddText.setObjectName("btnOutlineAddText")
        self.horizontalLayout_18.addWidget(self.btnOutlineAddText)
        self.btnOutlineRemoveItem = QtWidgets.QPushButton(self.layoutWidget)
        self.btnOutlineRemoveItem.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnOutlineRemoveItem.setIcon(icon)
        self.btnOutlineRemoveItem.setFlat(True)
        self.btnOutlineRemoveItem.setObjectName("btnOutlineRemoveItem")
        self.horizontalLayout_18.addWidget(self.btnOutlineRemoveItem)
        spacerItem15 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_18.addItem(spacerItem15)
        self.btnPlanShowDetails = QtWidgets.QPushButton(self.layoutWidget)
        self.btnPlanShowDetails.setText("")
        icon = QtGui.QIcon.fromTheme("text-x-generic")
        self.btnPlanShowDetails.setIcon(icon)
        self.btnPlanShowDetails.setCheckable(True)
        self.btnPlanShowDetails.setChecked(True)
        self.btnPlanShowDetails.setFlat(True)
        self.btnPlanShowDetails.setObjectName("btnPlanShowDetails")
        self.horizontalLayout_18.addWidget(self.btnPlanShowDetails)
        self.verticalLayout_14.addLayout(self.horizontalLayout_18)
        self.verticalLayout_27.addWidget(self.splitterOutlineH)
        self.tabMain.addTab(self.lytTabOutline, "")
        self.lytTabRedac = QtWidgets.QWidget()
        self.lytTabRedac.setObjectName("lytTabRedac")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self.lytTabRedac)
        self.verticalLayout_15.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.splitterRedacV = QtWidgets.QSplitter(self.lytTabRedac)
        self.splitterRedacV.setOrientation(QtCore.Qt.Vertical)
        self.splitterRedacV.setChildrenCollapsible(False)
        self.splitterRedacV.setObjectName("splitterRedacV")
        self.splitterRedacH = QtWidgets.QSplitter(self.splitterRedacV)
        self.splitterRedacH.setOrientation(QtCore.Qt.Horizontal)
        self.splitterRedacH.setChildrenCollapsible(False)
        self.splitterRedacH.setObjectName("splitterRedacH")
        self.treeRedacWidget = QtWidgets.QWidget(self.splitterRedacH)
        self.treeRedacWidget.setObjectName("treeRedacWidget")
        self.verticalLayout_30 = QtWidgets.QVBoxLayout(self.treeRedacWidget)
        self.verticalLayout_30.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_30.setObjectName("verticalLayout_30")
        self.treeRedacOutline = treeView(self.treeRedacWidget)
        self.treeRedacOutline.setAutoFillBackground(True)
        self.treeRedacOutline.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.treeRedacOutline.setEditTriggers(QtWidgets.QAbstractItemView.EditKeyPressed)
        self.treeRedacOutline.setObjectName("treeRedacOutline")
        self.treeRedacOutline.header().setVisible(False)
        self.verticalLayout_30.addWidget(self.treeRedacOutline)
        self.horizontalLayout_31 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_31.setObjectName("horizontalLayout_31")
        self.btnRedacAddFolder = QtWidgets.QPushButton(self.treeRedacWidget)
        self.btnRedacAddFolder.setText("")
        icon = QtGui.QIcon.fromTheme("folder-new")
        self.btnRedacAddFolder.setIcon(icon)
        self.btnRedacAddFolder.setFlat(True)
        self.btnRedacAddFolder.setObjectName("btnRedacAddFolder")
        self.horizontalLayout_31.addWidget(self.btnRedacAddFolder)
        self.btnRedacAddText = QtWidgets.QPushButton(self.treeRedacWidget)
        self.btnRedacAddText.setText("")
        icon = QtGui.QIcon.fromTheme("document-new")
        self.btnRedacAddText.setIcon(icon)
        self.btnRedacAddText.setFlat(True)
        self.btnRedacAddText.setObjectName("btnRedacAddText")
        self.horizontalLayout_31.addWidget(self.btnRedacAddText)
        self.btnRedacRemoveItem = QtWidgets.QPushButton(self.treeRedacWidget)
        self.btnRedacRemoveItem.setText("")
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnRedacRemoveItem.setIcon(icon)
        self.btnRedacRemoveItem.setFlat(True)
        self.btnRedacRemoveItem.setObjectName("btnRedacRemoveItem")
        self.horizontalLayout_31.addWidget(self.btnRedacRemoveItem)
        spacerItem16 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_31.addItem(spacerItem16)
        self.verticalLayout_30.addLayout(self.horizontalLayout_31)
        self.mainEditor = mainEditor(self.splitterRedacH)
        self.mainEditor.setObjectName("mainEditor")
        self.redacMetadata = metadataView(self.splitterRedacH)
        self.redacMetadata.setObjectName("redacMetadata")
        self.storylineView = storylineView(self.splitterRedacV)
        self.storylineView.setObjectName("storylineView")
        self.verticalLayout_15.addWidget(self.splitterRedacV)
        self.tabMain.addTab(self.lytTabRedac, "")
        self.lytTabDebug = QtWidgets.QWidget()
        self.lytTabDebug.setObjectName("lytTabDebug")
        self.verticalLayout_29 = QtWidgets.QVBoxLayout(self.lytTabDebug)
        self.verticalLayout_29.setObjectName("verticalLayout_29")
        self.tabWidget = QtWidgets.QTabWidget(self.lytTabDebug)
        self.tabWidget.setTabPosition(QtWidgets.QTabWidget.West)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_9 = QtWidgets.QWidget()
        self.tab_9.setObjectName("tab_9")
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout(self.tab_9)
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.tblDebugFlatData = QtWidgets.QTableView(self.tab_9)
        self.tblDebugFlatData.setObjectName("tblDebugFlatData")
        self.horizontalLayout_24.addWidget(self.tblDebugFlatData)
        self.tabWidget.addTab(self.tab_9, "")
        self.tab_10 = QtWidgets.QWidget()
        self.tab_10.setObjectName("tab_10")
        self.verticalLayout_19 = QtWidgets.QVBoxLayout(self.tab_10)
        self.verticalLayout_19.setObjectName("verticalLayout_19")
        self.tblDebugPersos = QtWidgets.QTableView(self.tab_10)
        self.tblDebugPersos.setObjectName("tblDebugPersos")
        self.verticalLayout_19.addWidget(self.tblDebugPersos)
        self.tblDebugPersosInfos = QtWidgets.QTableView(self.tab_10)
        self.tblDebugPersosInfos.setObjectName("tblDebugPersosInfos")
        self.verticalLayout_19.addWidget(self.tblDebugPersosInfos)
        self.tabWidget.addTab(self.tab_10, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.tblDebugPlots = QtWidgets.QTableView(self.tab_2)
        self.tblDebugPlots.setObjectName("tblDebugPlots")
        self.horizontalLayout_11.addWidget(self.tblDebugPlots)
        self.verticalLayout_22 = QtWidgets.QVBoxLayout()
        self.verticalLayout_22.setObjectName("verticalLayout_22")
        self.tblDebugPlotsPersos = QtWidgets.QTableView(self.tab_2)
        self.tblDebugPlotsPersos.setObjectName("tblDebugPlotsPersos")
        self.verticalLayout_22.addWidget(self.tblDebugPlotsPersos)
        self.tblDebugSubPlots = QtWidgets.QTableView(self.tab_2)
        self.tblDebugSubPlots.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
        self.tblDebugSubPlots.setObjectName("tblDebugSubPlots")
        self.verticalLayout_22.addWidget(self.tblDebugSubPlots)
        self.horizontalLayout_11.addLayout(self.verticalLayout_22)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.verticalLayout_34 = QtWidgets.QVBoxLayout(self.tab_5)
        self.verticalLayout_34.setObjectName("verticalLayout_34")
        self.treeDebugWorld = QtWidgets.QTreeView(self.tab_5)
        self.treeDebugWorld.setObjectName("treeDebugWorld")
        self.verticalLayout_34.addWidget(self.treeDebugWorld)
        self.tabWidget.addTab(self.tab_5, "")
        self.tab_20 = QtWidgets.QWidget()
        self.tab_20.setObjectName("tab_20")
        self.horizontalLayout_32 = QtWidgets.QHBoxLayout(self.tab_20)
        self.horizontalLayout_32.setObjectName("horizontalLayout_32")
        self.treeDebugOutline = QtWidgets.QTreeView(self.tab_20)
        self.treeDebugOutline.setWordWrap(True)
        self.treeDebugOutline.setObjectName("treeDebugOutline")
        self.horizontalLayout_32.addWidget(self.treeDebugOutline)
        self.tabWidget.addTab(self.tab_20, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.tab)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lstDebugLabels = QtWidgets.QListView(self.tab)
        self.lstDebugLabels.setObjectName("lstDebugLabels")
        self.horizontalLayout.addWidget(self.lstDebugLabels)
        self.lstDebugStatus = QtWidgets.QListView(self.tab)
        self.lstDebugStatus.setObjectName("lstDebugStatus")
        self.horizontalLayout.addWidget(self.lstDebugStatus)
        self.tabWidget.addTab(self.tab, "")
        self.verticalLayout_29.addWidget(self.tabWidget)
        self.tabMain.addTab(self.lytTabDebug, "")
        self.horizontalLayout_33.addWidget(self.tabMain)
        self.stack.addWidget(self.page_4)
        self.horizontalLayout_2.addWidget(self.stack)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1112, 30))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuRecents = QtWidgets.QMenu(self.menuFile)
        icon = QtGui.QIcon.fromTheme("folder-recent")
        self.menuRecents.setIcon(icon)
        self.menuRecents.setObjectName("menuRecents")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuTools = QtWidgets.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.mnuFormat = QtWidgets.QMenu(self.menuEdit)
        icon = QtGui.QIcon.fromTheme("format-text-bold")
        self.mnuFormat.setIcon(icon)
        self.mnuFormat.setObjectName("mnuFormat")
        self.mnuHeader = QtWidgets.QMenu(self.mnuFormat)
        self.mnuHeader.setObjectName("mnuHeader")
        self.menuView = QtWidgets.QMenu(self.menubar)
        self.menuView.setObjectName("menuView")
        self.menuMode = QtWidgets.QMenu(self.menuView)
        self.menuMode.setObjectName("menuMode")
        self.menuOrganize = QtWidgets.QMenu(self.menubar)
        self.menuOrganize.setObjectName("menuOrganize")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.dckCheatSheet = QtWidgets.QDockWidget(MainWindow)
        self.dckCheatSheet.setObjectName("dckCheatSheet")
        self.dockWidgetContents_5 = QtWidgets.QWidget()
        self.dockWidgetContents_5.setObjectName("dockWidgetContents_5")
        self.verticalLayout_39 = QtWidgets.QVBoxLayout(self.dockWidgetContents_5)
        self.verticalLayout_39.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_39.setObjectName("verticalLayout_39")
        self.cheatSheet = cheatSheet(self.dockWidgetContents_5)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.cheatSheet.setFont(font)
        self.cheatSheet.setObjectName("cheatSheet")
        self.verticalLayout_39.addWidget(self.cheatSheet)
        self.dckCheatSheet.setWidget(self.dockWidgetContents_5)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dckCheatSheet)
        self.dckSearch = QtWidgets.QDockWidget(MainWindow)
        self.dckSearch.setObjectName("dckSearch")
        self.dockWidgetContents_6 = QtWidgets.QWidget()
        self.dockWidgetContents_6.setObjectName("dockWidgetContents_6")
        self.verticalLayout_40 = QtWidgets.QVBoxLayout(self.dockWidgetContents_6)
        self.verticalLayout_40.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_40.setObjectName("verticalLayout_40")
        self.widget = search(self.dockWidgetContents_6)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.widget.setFont(font)
        self.widget.setObjectName("widget")
        self.verticalLayout_40.addWidget(self.widget)
        self.dckSearch.setWidget(self.dockWidgetContents_6)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dckSearch)
        self.dckNavigation = QtWidgets.QDockWidget(MainWindow)
        self.dckNavigation.setFeatures(QtWidgets.QDockWidget.DockWidgetClosable|QtWidgets.QDockWidget.DockWidgetMovable)
        self.dckNavigation.setObjectName("dckNavigation")
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.dockWidgetContents)
        self.verticalLayout_16.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.lstTabs = QtWidgets.QListWidget(self.dockWidgetContents)
        self.lstTabs.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.lstTabs.setObjectName("lstTabs")
        self.verticalLayout_16.addWidget(self.lstTabs)
        self.dckNavigation.setWidget(self.dockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.dckNavigation)
        self.actOpen = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("document-open")
        self.actOpen.setIcon(icon)
        self.actOpen.setObjectName("actOpen")
        self.actSave = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("document-save")
        self.actSave.setIcon(icon)
        self.actSave.setObjectName("actSave")
        self.actSaveAs = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("document-save-as")
        self.actSaveAs.setIcon(icon)
        self.actSaveAs.setObjectName("actSaveAs")
        self.actQuit = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("application-exit")
        self.actQuit.setIcon(icon)
        self.actQuit.setObjectName("actQuit")
        self.actShowHelp = QtWidgets.QAction(MainWindow)
        self.actShowHelp.setCheckable(True)
        self.actShowHelp.setChecked(True)
        icon = QtGui.QIcon.fromTheme("system-help")
        self.actShowHelp.setIcon(icon)
        self.actShowHelp.setObjectName("actShowHelp")
        self.actSpellcheck = QtWidgets.QAction(MainWindow)
        self.actSpellcheck.setCheckable(True)
        self.actSpellcheck.setChecked(True)
        icon = QtGui.QIcon.fromTheme("tools-check-spelling")
        self.actSpellcheck.setIcon(icon)
        self.actSpellcheck.setObjectName("actSpellcheck")
        self.actLabels = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("folder_color_picker")
        self.actLabels.setIcon(icon)
        self.actLabels.setObjectName("actLabels")
        self.actStatus = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("applications-development")
        self.actStatus.setIcon(icon)
        self.actStatus.setObjectName("actStatus")
        self.actViewTree = QtWidgets.QAction(MainWindow)
        self.actViewTree.setObjectName("actViewTree")
        self.actModeSimple = QtWidgets.QAction(MainWindow)
        self.actModeSimple.setCheckable(True)
        self.actModeSimple.setChecked(True)
        self.actModeSimple.setObjectName("actModeSimple")
        self.actModeFiction = QtWidgets.QAction(MainWindow)
        self.actModeFiction.setCheckable(True)
        self.actModeFiction.setObjectName("actModeFiction")
        self.actViewCork = QtWidgets.QAction(MainWindow)
        self.actViewCork.setObjectName("actViewCork")
        self.actViewOutline = QtWidgets.QAction(MainWindow)
        self.actViewOutline.setObjectName("actViewOutline")
        self.actSettings = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("preferences-system")
        self.actSettings.setIcon(icon)
        self.actSettings.setObjectName("actSettings")
        self.actCloseProject = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("window-close")
        self.actCloseProject.setIcon(icon)
        self.actCloseProject.setObjectName("actCloseProject")
        self.actCompile = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("document-export")
        self.actCompile.setIcon(icon)
        self.actCompile.setObjectName("actCompile")
        self.actToolFrequency = QtWidgets.QAction(MainWindow)
        self.actToolFrequency.setObjectName("actToolFrequency")
        self.actAbout = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("stock_view-details")
        self.actAbout.setIcon(icon)
        self.actAbout.setObjectName("actAbout")
        self.actImport = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("document-import")
        self.actImport.setIcon(icon)
        self.actImport.setObjectName("actImport")
        self.actCopy = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("edit-copy")
        self.actCopy.setIcon(icon)
        self.actCopy.setObjectName("actCopy")
        self.actCut = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("edit-cut")
        self.actCut.setIcon(icon)
        self.actCut.setObjectName("actCut")
        self.actPaste = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("edit-paste")
        self.actPaste.setIcon(icon)
        self.actPaste.setObjectName("actPaste")
        self.actSplitDialog = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("split")
        self.actSplitDialog.setIcon(icon)
        self.actSplitDialog.setObjectName("actSplitDialog")
        self.actSplitCursor = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("split")
        self.actSplitCursor.setIcon(icon)
        self.actSplitCursor.setObjectName("actSplitCursor")
        self.actMerge = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("merge")
        self.actMerge.setIcon(icon)
        self.actMerge.setObjectName("actMerge")
        self.actDuplicate = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("folder-copy")
        self.actDuplicate.setIcon(icon)
        self.actDuplicate.setObjectName("actDuplicate")
        self.actDelete = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("edit-delete")
        self.actDelete.setIcon(icon)
        self.actDelete.setObjectName("actDelete")
        self.actMoveUp = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("arrow-up")
        self.actMoveUp.setIcon(icon)
        self.actMoveUp.setObjectName("actMoveUp")
        self.actMoveDown = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("arrow-down")
        self.actMoveDown.setIcon(icon)
        self.actMoveDown.setObjectName("actMoveDown")
        self.actRename = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("edit-rename")
        self.actRename.setIcon(icon)
        self.actRename.setObjectName("actRename")
        self.actHeaderSetextL1 = QtWidgets.QAction(MainWindow)
        self.actHeaderSetextL1.setObjectName("actHeaderSetextL1")
        self.actHeaderSetextL2 = QtWidgets.QAction(MainWindow)
        self.actHeaderSetextL2.setObjectName("actHeaderSetextL2")
        self.actHeaderAtxL1 = QtWidgets.QAction(MainWindow)
        self.actHeaderAtxL1.setObjectName("actHeaderAtxL1")
        self.actHeaderAtxL2 = QtWidgets.QAction(MainWindow)
        self.actHeaderAtxL2.setObjectName("actHeaderAtxL2")
        self.actHeaderAtxL3 = QtWidgets.QAction(MainWindow)
        self.actHeaderAtxL3.setObjectName("actHeaderAtxL3")
        self.actHeaderAtxL4 = QtWidgets.QAction(MainWindow)
        self.actHeaderAtxL4.setObjectName("actHeaderAtxL4")
        self.actHeaderAtxL5 = QtWidgets.QAction(MainWindow)
        self.actHeaderAtxL5.setObjectName("actHeaderAtxL5")
        self.actHeaderAtxL6 = QtWidgets.QAction(MainWindow)
        self.actHeaderAtxL6.setObjectName("actHeaderAtxL6")
        self.actFormatBold = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("format-text-bold")
        self.actFormatBold.setIcon(icon)
        self.actFormatBold.setObjectName("actFormatBold")
        self.actFormatItalic = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("format-text-italic")
        self.actFormatItalic.setIcon(icon)
        self.actFormatItalic.setObjectName("actFormatItalic")
        self.actFormatStrike = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("format-text-strikethrough")
        self.actFormatStrike.setIcon(icon)
        self.actFormatStrike.setObjectName("actFormatStrike")
        self.actFormatVerbatim = QtWidgets.QAction(MainWindow)
        self.actFormatVerbatim.setObjectName("actFormatVerbatim")
        self.actFormatSuperscript = QtWidgets.QAction(MainWindow)
        self.actFormatSuperscript.setObjectName("actFormatSuperscript")
        self.actFormatSubscript = QtWidgets.QAction(MainWindow)
        self.actFormatSubscript.setObjectName("actFormatSubscript")
        self.actFormatCommentBlock = QtWidgets.QAction(MainWindow)
        self.actFormatCommentBlock.setObjectName("actFormatCommentBlock")
        self.actFormatClear = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("format-text-none")
        self.actFormatClear.setIcon(icon)
        self.actFormatClear.setObjectName("actFormatClear")
        self.actFormatCommentLines = QtWidgets.QAction(MainWindow)
        self.actFormatCommentLines.setObjectName("actFormatCommentLines")
        self.actFormatOrderedList = QtWidgets.QAction(MainWindow)
        self.actFormatOrderedList.setObjectName("actFormatOrderedList")
        self.actFormatList = QtWidgets.QAction(MainWindow)
        icon = QtGui.QIcon.fromTheme("view-list")
        self.actFormatList.setIcon(icon)
        self.actFormatList.setObjectName("actFormatList")
        self.actFormatBlockquote = QtWidgets.QAction(MainWindow)
        self.actFormatBlockquote.setObjectName("actFormatBlockquote")
        self.menuFile.addAction(self.actOpen)
        self.menuFile.addAction(self.menuRecents.menuAction())
        self.menuFile.addAction(self.actSave)
        self.menuFile.addAction(self.actSaveAs)
        self.menuFile.addAction(self.actCloseProject)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actImport)
        self.menuFile.addAction(self.actCompile)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actQuit)
        self.menuHelp.addAction(self.actShowHelp)
        self.menuHelp.addAction(self.actAbout)
        self.menuTools.addAction(self.actSpellcheck)
        self.menuTools.addAction(self.actToolFrequency)
        self.mnuHeader.addAction(self.actHeaderSetextL1)
        self.mnuHeader.addAction(self.actHeaderSetextL2)
        self.mnuHeader.addSeparator()
        self.mnuHeader.addAction(self.actHeaderAtxL1)
        self.mnuHeader.addAction(self.actHeaderAtxL2)
        self.mnuHeader.addAction(self.actHeaderAtxL3)
        self.mnuHeader.addAction(self.actHeaderAtxL4)
        self.mnuHeader.addAction(self.actHeaderAtxL5)
        self.mnuHeader.addAction(self.actHeaderAtxL6)
        self.mnuFormat.addAction(self.mnuHeader.menuAction())
        self.mnuFormat.addSeparator()
        self.mnuFormat.addAction(self.actFormatBold)
        self.mnuFormat.addAction(self.actFormatItalic)
        self.mnuFormat.addAction(self.actFormatStrike)
        self.mnuFormat.addAction(self.actFormatVerbatim)
        self.mnuFormat.addAction(self.actFormatSuperscript)
        self.mnuFormat.addAction(self.actFormatSubscript)
        self.mnuFormat.addAction(self.actFormatCommentLines)
        self.mnuFormat.addSeparator()
        self.mnuFormat.addAction(self.actFormatList)
        self.mnuFormat.addAction(self.actFormatOrderedList)
        self.mnuFormat.addAction(self.actFormatBlockquote)
        self.mnuFormat.addAction(self.actFormatCommentBlock)
        self.mnuFormat.addSeparator()
        self.mnuFormat.addAction(self.actFormatClear)
        self.menuEdit.addAction(self.actCut)
        self.menuEdit.addAction(self.actCopy)
        self.menuEdit.addAction(self.actPaste)
        self.menuEdit.addAction(self.actDelete)
        self.menuEdit.addAction(self.actRename)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.mnuFormat.menuAction())
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actLabels)
        self.menuEdit.addAction(self.actStatus)
        self.menuEdit.addAction(self.actSettings)
        self.menuMode.addAction(self.actModeSimple)
        self.menuMode.addAction(self.actModeFiction)
        self.menuView.addAction(self.menuMode.menuAction())
        self.menuView.addSeparator()
        self.menuOrganize.addAction(self.actMoveUp)
        self.menuOrganize.addAction(self.actMoveDown)
        self.menuOrganize.addSeparator()
        self.menuOrganize.addAction(self.actMerge)
        self.menuOrganize.addAction(self.actSplitDialog)
        self.menuOrganize.addAction(self.actSplitCursor)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuOrganize.menuAction())
        self.menubar.addAction(self.menuView.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        self.stack.setCurrentIndex(1)
        self.tabMain.setCurrentIndex(0)
        self.tabSummary.setCurrentIndex(0)
        self.tabPersos.setCurrentIndex(0)
        self.tabPlot.setCurrentIndex(0)
        self.comboBox_2.setCurrentIndex(0)
        self.stkPlotSummary.setCurrentIndex(0)
        self.tabWorld.setCurrentIndex(0)
        self.tabWidget.setCurrentIndex(0)
        self.comboBox_2.currentIndexChanged['int'].connect(self.stkPlotSummary.setCurrentIndex)
        self.btnPlanShowDetails.toggled['bool'].connect(self.frame.setVisible)
        self.cmbSummary.currentIndexChanged['int'].connect(self.tabSummary.setCurrentIndex)
        self.tabSummary.currentChanged['int'].connect(self.cmbSummary.setCurrentIndex)
        self.btnShowSubPlotSummary.toggled['bool'].connect(self.grpSubPlotSummary.setVisible)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.tabMain, self.txtGeneralTitle)
        MainWindow.setTabOrder(self.txtGeneralTitle, self.txtGeneralSubtitle)
        MainWindow.setTabOrder(self.txtGeneralSubtitle, self.txtGeneralSerie)
        MainWindow.setTabOrder(self.txtGeneralSerie, self.txtGeneralVolume)
        MainWindow.setTabOrder(self.txtGeneralVolume, self.txtGeneralGenre)
        MainWindow.setTabOrder(self.txtGeneralGenre, self.txtGeneralLicense)
        MainWindow.setTabOrder(self.txtGeneralLicense, self.txtGeneralAuthor)
        MainWindow.setTabOrder(self.txtGeneralAuthor, self.txtGeneralEmail)
        MainWindow.setTabOrder(self.txtGeneralEmail, self.cmbSummary)
        MainWindow.setTabOrder(self.cmbSummary, self.txtSummarySentence)
        MainWindow.setTabOrder(self.txtSummarySentence, self.txtSummarySentence_2)
        MainWindow.setTabOrder(self.txtSummarySentence_2, self.txtSummaryPara)
        MainWindow.setTabOrder(self.txtSummaryPara, self.txtSummaryPara_2)
        MainWindow.setTabOrder(self.txtSummaryPara_2, self.txtSummaryPage)
        MainWindow.setTabOrder(self.txtSummaryPage, self.txtSummaryPage_2)
        MainWindow.setTabOrder(self.txtSummaryPage_2, self.txtSummaryFull)
        MainWindow.setTabOrder(self.txtSummaryFull, self.btnStepThree)
        MainWindow.setTabOrder(self.btnStepThree, self.btnStepTwo)
        MainWindow.setTabOrder(self.btnStepTwo, self.btnStepFive)
        MainWindow.setTabOrder(self.btnStepFive, self.btnStepSeven)
        MainWindow.setTabOrder(self.btnStepSeven, self.txtSummarySituation)
        MainWindow.setTabOrder(self.txtSummarySituation, self.lstCharacters)
        MainWindow.setTabOrder(self.lstCharacters, self.btnAddPerso)
        MainWindow.setTabOrder(self.btnAddPerso, self.btnRmPerso)
        MainWindow.setTabOrder(self.btnRmPerso, self.txtPersosFilter)
        MainWindow.setTabOrder(self.txtPersosFilter, self.tabPersos)
        MainWindow.setTabOrder(self.tabPersos, self.scrollAreaPersoInfos)
        MainWindow.setTabOrder(self.scrollAreaPersoInfos, self.txtPersoName)
        MainWindow.setTabOrder(self.txtPersoName, self.btnPersoColor)
        MainWindow.setTabOrder(self.btnPersoColor, self.txtPersoMotivation)
        MainWindow.setTabOrder(self.txtPersoMotivation, self.txtPersoGoal)
        MainWindow.setTabOrder(self.txtPersoGoal, self.txtPersoConflict)
        MainWindow.setTabOrder(self.txtPersoConflict, self.txtPersoEpiphany)
        MainWindow.setTabOrder(self.txtPersoEpiphany, self.txtPersoSummarySentence)
        MainWindow.setTabOrder(self.txtPersoSummarySentence, self.txtPersoSummaryPara)
        MainWindow.setTabOrder(self.txtPersoSummaryPara, self.btnStepFour)
        MainWindow.setTabOrder(self.btnStepFour, self.txtPersoSummaryFull)
        MainWindow.setTabOrder(self.txtPersoSummaryFull, self.btnStepSix)
        MainWindow.setTabOrder(self.btnStepSix, self.txtPersoNotes)
        MainWindow.setTabOrder(self.txtPersoNotes, self.tblPersoInfos)
        MainWindow.setTabOrder(self.tblPersoInfos, self.btnPersoAddInfo)
        MainWindow.setTabOrder(self.btnPersoAddInfo, self.btnPersoRmInfo)
        MainWindow.setTabOrder(self.btnPersoRmInfo, self.lineEdit)
        MainWindow.setTabOrder(self.lineEdit, self.btnStepEight)
        MainWindow.setTabOrder(self.btnStepEight, self.lstPlots)
        MainWindow.setTabOrder(self.lstPlots, self.btnAddPlot)
        MainWindow.setTabOrder(self.btnAddPlot, self.btnRmPlot)
        MainWindow.setTabOrder(self.btnRmPlot, self.txtPlotFilter)
        MainWindow.setTabOrder(self.txtPlotFilter, self.tabPlot)
        MainWindow.setTabOrder(self.tabPlot, self.txtPlotName)
        MainWindow.setTabOrder(self.txtPlotName, self.lstPlotPerso)
        MainWindow.setTabOrder(self.lstPlotPerso, self.btnAddPlotPerso)
        MainWindow.setTabOrder(self.btnAddPlotPerso, self.btnRmPlotPerso)
        MainWindow.setTabOrder(self.btnRmPlotPerso, self.txtPlotDescription)
        MainWindow.setTabOrder(self.txtPlotDescription, self.txtPlotResult)
        MainWindow.setTabOrder(self.txtPlotResult, self.lstSubPlots)
        MainWindow.setTabOrder(self.lstSubPlots, self.txtSubPlotSummary)
        MainWindow.setTabOrder(self.txtSubPlotSummary, self.btnAddSubPlot)
        MainWindow.setTabOrder(self.btnAddSubPlot, self.btnRmSubPlot)
        MainWindow.setTabOrder(self.btnRmSubPlot, self.btnShowSubPlotSummary)
        MainWindow.setTabOrder(self.btnShowSubPlotSummary, self.comboBox_2)
        MainWindow.setTabOrder(self.comboBox_2, self.txtPlotSummaryPara)
        MainWindow.setTabOrder(self.txtPlotSummaryPara, self.txtPlotSummaryPage)
        MainWindow.setTabOrder(self.txtPlotSummaryPage, self.txtPlotSummaryFull)
        MainWindow.setTabOrder(self.txtPlotSummaryFull, self.treeWorld)
        MainWindow.setTabOrder(self.treeWorld, self.btnAddWorld)
        MainWindow.setTabOrder(self.btnAddWorld, self.btnRmWorld)
        MainWindow.setTabOrder(self.btnRmWorld, self.txtWorldFilter)
        MainWindow.setTabOrder(self.txtWorldFilter, self.btnWorldEmptyData)
        MainWindow.setTabOrder(self.btnWorldEmptyData, self.tabWorld)
        MainWindow.setTabOrder(self.tabWorld, self.txtWorldName)
        MainWindow.setTabOrder(self.txtWorldName, self.txtWorldDescription)
        MainWindow.setTabOrder(self.txtWorldDescription, self.txtWorldPassion)
        MainWindow.setTabOrder(self.txtWorldPassion, self.txtWorldConflict)
        MainWindow.setTabOrder(self.txtWorldConflict, self.lstOutlinePlots)
        MainWindow.setTabOrder(self.lstOutlinePlots, self.treeOutlineOutline)
        MainWindow.setTabOrder(self.treeOutlineOutline, self.btnOutlineAddFolder)
        MainWindow.setTabOrder(self.btnOutlineAddFolder, self.btnOutlineAddText)
        MainWindow.setTabOrder(self.btnOutlineAddText, self.btnOutlineRemoveItem)
        MainWindow.setTabOrder(self.btnOutlineRemoveItem, self.btnPlanShowDetails)
        MainWindow.setTabOrder(self.btnPlanShowDetails, self.treeRedacOutline)
        MainWindow.setTabOrder(self.treeRedacOutline, self.btnRedacAddFolder)
        MainWindow.setTabOrder(self.btnRedacAddFolder, self.btnRedacAddText)
        MainWindow.setTabOrder(self.btnRedacAddText, self.btnRedacRemoveItem)
        MainWindow.setTabOrder(self.btnRedacRemoveItem, self.tabWidget)
        MainWindow.setTabOrder(self.tabWidget, self.tblDebugFlatData)
        MainWindow.setTabOrder(self.tblDebugFlatData, self.tblDebugPersos)
        MainWindow.setTabOrder(self.tblDebugPersos, self.tblDebugPersosInfos)
        MainWindow.setTabOrder(self.tblDebugPersosInfos, self.tblDebugPlots)
        MainWindow.setTabOrder(self.tblDebugPlots, self.tblDebugPlotsPersos)
        MainWindow.setTabOrder(self.tblDebugPlotsPersos, self.tblDebugSubPlots)
        MainWindow.setTabOrder(self.tblDebugSubPlots, self.treeDebugWorld)
        MainWindow.setTabOrder(self.treeDebugWorld, self.treeDebugOutline)
        MainWindow.setTabOrder(self.treeDebugOutline, self.lstDebugLabels)
        MainWindow.setTabOrder(self.lstDebugLabels, self.lstDebugStatus)
        MainWindow.setTabOrder(self.lstDebugStatus, self.lstTabs)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        self.grpBookInfos.setTitle(_translate("MainWindow", "Book information"))
        self.label_10.setText(_translate("MainWindow", "Title"))
        self.label_11.setText(_translate("MainWindow", "Subtitle"))
        self.label_12.setText(_translate("MainWindow", "Series"))
        self.label_13.setText(_translate("MainWindow", "Volume"))
        self.label_14.setText(_translate("MainWindow", "Genre"))
        self.label_16.setText(_translate("MainWindow", "License"))
        self.grpAuthor.setTitle(_translate("MainWindow", "Author"))
        self.label_15.setText(_translate("MainWindow", "Name"))
        self.label_19.setText(_translate("MainWindow", "Email"))
        self.tabMain.setTabText(self.tabMain.indexOf(self.lytTabOverview), _translate("MainWindow", "General"))
        self.label_9.setText(_translate("MainWindow", "Situation:"))
        self.label_29.setText(_translate("MainWindow", "Summary:"))
        self.cmbSummary.setItemText(0, _translate("MainWindow", "One sentence"))
        self.cmbSummary.setItemText(1, _translate("MainWindow", "One paragraph"))
        self.cmbSummary.setItemText(2, _translate("MainWindow", "One page"))
        self.cmbSummary.setItemText(3, _translate("MainWindow", "Full"))
        self.label.setText(_translate("MainWindow", "One sentence summary"))
        self.label_21.setText(_translate("MainWindow", "One sentence summary"))
        self.label_2.setText(_translate("MainWindow", "One paragraph summary"))
        self.label_22.setText(_translate("MainWindow", "One paragraph summary"))
        self.label_17.setText(_translate("MainWindow", "Expand each sentence of your one paragraph summary to a paragraph"))
        self.label_23.setText(_translate("MainWindow", "One page summary"))
        self.label_20.setText(_translate("MainWindow", "Full summary"))
        self.btnStepThree.setText(_translate("MainWindow", "Next"))
        self.btnStepTwo.setText(_translate("MainWindow", "Next"))
        self.btnStepFive.setText(_translate("MainWindow", "Next"))
        self.btnStepSeven.setText(_translate("MainWindow", "Next"))
        self.txtSummarySituation.setPlaceholderText(_translate("MainWindow", "What if...?"))
        self.tabMain.setTabText(self.tabMain.indexOf(self.lytTabSummary), _translate("MainWindow", "Summary"))
        self.groupBox.setTitle(_translate("MainWindow", "Names"))
        self.txtPersosFilter.setPlaceholderText(_translate("MainWindow", "Filter"))
        self.label_4.setText(_translate("MainWindow", "Motivation"))
        self.label_5.setText(_translate("MainWindow", "Goal"))
        self.label_6.setText(_translate("MainWindow", "Conflict"))
        self.label_7.setText(_translate("MainWindow", "Epiphany"))
        self.label_24.setText(_translate("MainWindow", "<html><head/><body><p align=\"right\">One sentence<br/>summary</p></body></html>"))
        self.label_8.setText(_translate("MainWindow", "<html><head/><body><p align=\"right\">One paragraph<br/>summary</p></body></html>"))
        self.btnStepFour.setText(_translate("MainWindow", "Next"))
        self.label_18.setText(_translate("MainWindow", "Importance"))
        self.label_3.setText(_translate("MainWindow", "Name"))
        self.tabPersos.setTabText(self.tabPersos.indexOf(self.info), _translate("MainWindow", "Basic info"))
        self.btnStepSix.setText(_translate("MainWindow", "Next"))
        self.tabPersos.setTabText(self.tabPersos.indexOf(self.tab_11), _translate("MainWindow", "Summary"))
        self.tabPersos.setTabText(self.tabPersos.indexOf(self.tab_19), _translate("MainWindow", "Notes"))
        self.lineEdit.setPlaceholderText(_translate("MainWindow", "Filter"))
        self.btnStepEight.setText(_translate("MainWindow", "Next"))
        self.tabPersos.setTabText(self.tabPersos.indexOf(self.tab_12), _translate("MainWindow", "Detailed info"))
        self.tabMain.setTabText(self.tabMain.indexOf(self.lytTabPersos), _translate("MainWindow", "Characters"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Plots"))
        self.txtPlotFilter.setPlaceholderText(_translate("MainWindow", "Filter"))
        self.label_25.setText(_translate("MainWindow", "Plot"))
        self.label_31.setText(_translate("MainWindow", "Importance"))
        self.label_26.setText(_translate("MainWindow", "Character(s)"))
        self.label_27.setText(_translate("MainWindow", "Description"))
        self.label_28.setText(_translate("MainWindow", "Result"))
        self.tabPlot.setTabText(self.tabPlot.indexOf(self.infos_2), _translate("MainWindow", "Basic info"))
        self.grpSubPlotSummary.setTitle(_translate("MainWindow", "Summary:"))
        self.btnAddSubPlot.setToolTip(_translate("MainWindow", "Add plot step"))
        self.btnRmSubPlot.setToolTip(_translate("MainWindow", "Remove selected plot step(s)"))
        self.tabPlot.setTabText(self.tabPlot.indexOf(self.tab_15), _translate("MainWindow", "Resolution steps"))
        self.grpPlotSummary.setTitle(_translate("MainWindow", "Summary"))
        self.comboBox_2.setItemText(0, _translate("MainWindow", "One paragraph"))
        self.comboBox_2.setItemText(1, _translate("MainWindow", "One page"))
        self.comboBox_2.setItemText(2, _translate("MainWindow", "Full"))
        self.tabMain.setTabText(self.tabMain.indexOf(self.lytTabPlot), _translate("MainWindow", "Plots"))
        self.txtWorldFilter.setPlaceholderText(_translate("MainWindow", "Filter"))
        self.btnWorldEmptyData.setToolTip(_translate("MainWindow", "Populates with empty data"))
        self.btnWorldEmptyData.setStatusTip(_translate("MainWindow", "Populates with empty data"))
        self.label_30.setText(_translate("MainWindow", "Name"))
        self.label_32.setText(_translate("MainWindow", "Description"))
        self.tabWorld.setTabText(self.tabWorld.indexOf(self.tab_3), _translate("MainWindow", "General"))
        self.label_33.setText(_translate("MainWindow", "Source of passion"))
        self.label_34.setText(_translate("MainWindow", "Source of conflict"))
        self.tabWorld.setTabText(self.tabWorld.indexOf(self.tab_4), _translate("MainWindow", "More"))
        self.tabMain.setTabText(self.tabMain.indexOf(self.lytTabContext), _translate("MainWindow", "World"))
        self.tabMain.setTabText(self.tabMain.indexOf(self.lytTabOutline), _translate("MainWindow", "Outline"))
        self.tabMain.setTabText(self.tabMain.indexOf(self.lytTabRedac), _translate("MainWindow", "Editor"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_9), _translate("MainWindow", "FlatData"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_10), _translate("MainWindow", "Persos"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("MainWindow", "Plots"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), _translate("MainWindow", "World"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_20), _translate("MainWindow", "Outline"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Labels"))
        self.tabMain.setTabText(self.tabMain.indexOf(self.lytTabDebug), _translate("MainWindow", "Debug"))
        self.menuFile.setTitle(_translate("MainWindow", "&File"))
        self.menuRecents.setTitle(_translate("MainWindow", "&Recent"))
        self.menuHelp.setTitle(_translate("MainWindow", "&Help"))
        self.menuTools.setTitle(_translate("MainWindow", "&Tools"))
        self.menuEdit.setTitle(_translate("MainWindow", "&Edit"))
        self.mnuFormat.setTitle(_translate("MainWindow", "&Format"))
        self.mnuHeader.setTitle(_translate("MainWindow", "&Header"))
        self.menuView.setTitle(_translate("MainWindow", "&View"))
        self.menuMode.setTitle(_translate("MainWindow", "&Mode"))
        self.menuOrganize.setTitle(_translate("MainWindow", "Organi&ze"))
        self.dckCheatSheet.setWindowTitle(_translate("MainWindow", "&Cheat sheet"))
        self.dckSearch.setWindowTitle(_translate("MainWindow", "Sea&rch"))
        self.dckNavigation.setWindowTitle(_translate("MainWindow", "&Navigation"))
        self.actOpen.setText(_translate("MainWindow", "&Open"))
        self.actOpen.setShortcut(_translate("MainWindow", "Ctrl+O"))
        self.actSave.setText(_translate("MainWindow", "&Save"))
        self.actSave.setShortcut(_translate("MainWindow", "Ctrl+S"))
        self.actSaveAs.setText(_translate("MainWindow", "Sa&ve as..."))
        self.actSaveAs.setShortcut(_translate("MainWindow", "Ctrl+Shift+S"))
        self.actQuit.setText(_translate("MainWindow", "&Quit"))
        self.actQuit.setShortcut(_translate("MainWindow", "Ctrl+Q"))
        self.actShowHelp.setText(_translate("MainWindow", "&Show help texts"))
        self.actShowHelp.setShortcut(_translate("MainWindow", "Ctrl+Shift+B"))
        self.actSpellcheck.setText(_translate("MainWindow", "&Spellcheck"))
        self.actSpellcheck.setShortcut(_translate("MainWindow", "F9"))
        self.actLabels.setText(_translate("MainWindow", "&Labels..."))
        self.actStatus.setText(_translate("MainWindow", "&Status..."))
        self.actViewTree.setText(_translate("MainWindow", "Tree"))
        self.actModeSimple.setText(_translate("MainWindow", "&Simple"))
        self.actModeFiction.setText(_translate("MainWindow", "&Fiction"))
        self.actViewCork.setText(_translate("MainWindow", "Index cards"))
        self.actViewOutline.setText(_translate("MainWindow", "Outline"))
        self.actSettings.setText(_translate("MainWindow", "S&ettings"))
        self.actSettings.setShortcut(_translate("MainWindow", "F8"))
        self.actCloseProject.setText(_translate("MainWindow", "&Close project"))
        self.actCompile.setText(_translate("MainWindow", "Co&mpile"))
        self.actCompile.setShortcut(_translate("MainWindow", "F6"))
        self.actToolFrequency.setText(_translate("MainWindow", "&Frequency Analyzer"))
        self.actAbout.setText(_translate("MainWindow", "&About"))
        self.actAbout.setToolTip(_translate("MainWindow", "About Manuskript"))
        self.actImport.setText(_translate("MainWindow", "&Import…"))
        self.actImport.setShortcut(_translate("MainWindow", "F7"))
        self.actCopy.setText(_translate("MainWindow", "&Copy"))
        self.actCopy.setShortcut(_translate("MainWindow", "Ctrl+C"))
        self.actCut.setText(_translate("MainWindow", "C&ut"))
        self.actCut.setShortcut(_translate("MainWindow", "Ctrl+X"))
        self.actPaste.setText(_translate("MainWindow", "&Paste"))
        self.actPaste.setShortcut(_translate("MainWindow", "Ctrl+V"))
        self.actSplitDialog.setText(_translate("MainWindow", "&Split…"))
        self.actSplitDialog.setShortcut(_translate("MainWindow", "Ctrl+Shift+K"))
        self.actSplitCursor.setText(_translate("MainWindow", "Sp&lit at cursor"))
        self.actSplitCursor.setShortcut(_translate("MainWindow", "Ctrl+K"))
        self.actMerge.setText(_translate("MainWindow", "M&erge"))
        self.actMerge.setShortcut(_translate("MainWindow", "Ctrl+M"))
        self.actDuplicate.setText(_translate("MainWindow", "Dupl&icate"))
        self.actDelete.setText(_translate("MainWindow", "&Delete"))
        self.actDelete.setShortcut(_translate("MainWindow", "Del"))
        self.actMoveUp.setText(_translate("MainWindow", "&Move Up"))
        self.actMoveUp.setShortcut(_translate("MainWindow", "Ctrl+Shift+Up"))
        self.actMoveDown.setText(_translate("MainWindow", "M&ove Down"))
        self.actMoveDown.setShortcut(_translate("MainWindow", "Ctrl+Shift+Down"))
        self.actRename.setText(_translate("MainWindow", "&Rename"))
        self.actRename.setShortcut(_translate("MainWindow", "F2"))
        self.actHeaderSetextL1.setText(_translate("MainWindow", "&Level 1 (setext)"))
        self.actHeaderSetextL1.setShortcut(_translate("MainWindow", "Ctrl+Alt+1"))
        self.actHeaderSetextL2.setText(_translate("MainWindow", "Level &2"))
        self.actHeaderSetextL2.setShortcut(_translate("MainWindow", "Ctrl+Alt+2"))
        self.actHeaderAtxL1.setText(_translate("MainWindow", "Level &1 (atx)"))
        self.actHeaderAtxL1.setShortcut(_translate("MainWindow", "Ctrl+1"))
        self.actHeaderAtxL2.setText(_translate("MainWindow", "L&evel 2"))
        self.actHeaderAtxL2.setShortcut(_translate("MainWindow", "Ctrl+2"))
        self.actHeaderAtxL3.setText(_translate("MainWindow", "Level &3"))
        self.actHeaderAtxL3.setShortcut(_translate("MainWindow", "Ctrl+3"))
        self.actHeaderAtxL4.setText(_translate("MainWindow", "Level &4"))
        self.actHeaderAtxL4.setShortcut(_translate("MainWindow", "Ctrl+4"))
        self.actHeaderAtxL5.setText(_translate("MainWindow", "Level &5"))
        self.actHeaderAtxL5.setShortcut(_translate("MainWindow", "Ctrl+5"))
        self.actHeaderAtxL6.setText(_translate("MainWindow", "Level &6"))
        self.actHeaderAtxL6.setShortcut(_translate("MainWindow", "Ctrl+6"))
        self.actFormatBold.setText(_translate("MainWindow", "&Bold"))
        self.actFormatBold.setShortcut(_translate("MainWindow", "Ctrl+B"))
        self.actFormatItalic.setText(_translate("MainWindow", "&Italic"))
        self.actFormatItalic.setShortcut(_translate("MainWindow", "Ctrl+I"))
        self.actFormatStrike.setText(_translate("MainWindow", "&Strike"))
        self.actFormatVerbatim.setText(_translate("MainWindow", "&Verbatim"))
        self.actFormatSuperscript.setText(_translate("MainWindow", "Su&perscript"))
        self.actFormatSuperscript.setShortcut(_translate("MainWindow", "Ctrl++"))
        self.actFormatSubscript.setText(_translate("MainWindow", "Subsc&ript"))
        self.actFormatSubscript.setShortcut(_translate("MainWindow", "Ctrl+-"))
        self.actFormatCommentBlock.setText(_translate("MainWindow", "Co&mment block"))
        self.actFormatCommentBlock.setShortcut(_translate("MainWindow", "Ctrl+Shift+C"))
        self.actFormatClear.setText(_translate("MainWindow", "Clear &formats"))
        self.actFormatClear.setShortcut(_translate("MainWindow", "Ctrl+0"))
        self.actFormatCommentLines.setText(_translate("MainWindow", "&Comment line(s)"))
        self.actFormatCommentLines.setShortcut(_translate("MainWindow", "Ctrl+D"))
        self.actFormatOrderedList.setText(_translate("MainWindow", "&Ordered list"))
        self.actFormatList.setText(_translate("MainWindow", "&Unordered list"))
        self.actFormatBlockquote.setText(_translate("MainWindow", "B&lockquote"))

from manuskript.ui.cheatSheet import cheatSheet
from manuskript.ui.editors.mainEditor import mainEditor
from manuskript.ui.search import search
from manuskript.ui.views.MDEditCompleter import MDEditCompleter
from manuskript.ui.views.basicItemView import basicItemView
from manuskript.ui.views.characterTreeView import characterTreeView
from manuskript.ui.views.lineEditView import lineEditView
from manuskript.ui.views.metadataView import metadataView
from manuskript.ui.views.outlineView import outlineView
from manuskript.ui.views.plotTreeView import plotTreeView
from manuskript.ui.views.sldImportance import sldImportance
from manuskript.ui.views.storylineView import storylineView
from manuskript.ui.views.treeView import treeView
from manuskript.ui.welcome import welcome



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'manuskript/ui/editors/editorWidget_ui.ui'
#
# Created by: PyQt5 UI code generator 5.5.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_editorWidget_ui(object):
    def setupUi(self, editorWidget_ui):
        editorWidget_ui.setObjectName("editorWidget_ui")
        editorWidget_ui.resize(400, 300)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(editorWidget_ui)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.stack = QtWidgets.QStackedWidget(editorWidget_ui)
        self.stack.setObjectName("stack")
        self.text = QtWidgets.QWidget()
        self.text.setObjectName("text")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.text)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.txtRedacText = MDEditView(self.text)
        self.txtRedacText.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.txtRedacText.setObjectName("txtRedacText")
        self.horizontalLayout_2.addWidget(self.txtRedacText)
        self.stack.addWidget(self.text)
        self.folder = QtWidgets.QWidget()
        self.folder.setObjectName("folder")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.folder)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.scroll = QtWidgets.QScrollArea(self.folder)
        self.scroll.setAutoFillBackground(True)
        self.scroll.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.scroll.setWidgetResizable(True)
        self.scroll.setObjectName("scroll")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 400, 300))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.scroll.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout.addWidget(self.scroll)
        self.stack.addWidget(self.folder)
        self.cork = QtWidgets.QWidget()
        self.cork.setObjectName("cork")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.cork)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.corkView = corkView(self.cork)
        self.corkView.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.corkView.setObjectName("corkView")
        self.horizontalLayout_3.addWidget(self.corkView)
        self.stack.addWidget(self.cork)
        self.outline = QtWidgets.QWidget()
        self.outline.setObjectName("outline")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.outline)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.outlineView = outlineView(self.outline)
        self.outlineView.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.outlineView.setObjectName("outlineView")
        self.verticalLayout_3.addWidget(self.outlineView)
        self.stack.addWidget(self.outline)
        self.verticalLayout_2.addWidget(self.stack)

        self.retranslateUi(editorWidget_ui)
        self.stack.setCurrentIndex(3)
        QtCore.QMetaObject.connectSlotsByName(editorWidget_ui)

    def retranslateUi(self, editorWidget_ui):
        _translate = QtCore.QCoreApplication.translate
        editorWidget_ui.setWindowTitle(_translate("editorWidget_ui", "Form"))

from manuskript.ui.views.MDEditView import MDEditView
from manuskript.ui.views.corkView import corkView
from manuskript.ui.views.outlineView import outlineView



#!/usr/bin/python
# -*- coding: utf8 -*-
import re

from PyQt5.QtCore import Qt
from PyQt5.QtGui import QTextCharFormat, QFont, QTextCursor, QFontMetrics

from manuskript.ui.highlighters import BasicHighlighter


class MMDHighlighter(BasicHighlighter):

    MARKDOWN_REGEX = {
        'Bold':             r'(\*\*)(.+?)(\*\*)',
        'Bold2':            '(__)(.+?)(__)',
        'Italic':           r'(\*)([^\*].+?[^\*])(\*)',
        'Italic2':          '(_)([^_].+?[^_])(_)',
        'Title':            r'^(#+)(\s*)(.*)(#*)',
        'HTML':             '<.+?>',
        'Blockquotes':      '^(> )+.*$',
        'OrderedList':      r'^\d+\.\s+',
        'UnorderedList':    r'^[\*\+-]\s+',
        'Code':             r'^\s{4,}.*$',
        'Links-inline':     r'(\[)(.*?)(\])(\()(.*?)(\))',
        'Links-ref':        r'(\[)(.*?)(\])\s?(\[)(.*?)(\])',
        'Links-ref2':       r'^\s{,3}(\[)(.*?)(\]:)\s+([^\s]*)\s*(.*?)*$',
    }

    def __init__(self, editor, style="Default"):
        BasicHighlighter.__init__(self, editor)

        self.editor = editor

        self.rules = {}
        for key in self.MARKDOWN_REGEX:
            self.rules[key] = re.compile(self.MARKDOWN_REGEX[key])

    def doHighlightBlock(self, text):
        """
        A quick-n-dirty very basic highlighter, that fails in most non-trivial cases. And is ugly.
        """

        # Creates textCharFormat
        cfOperator = QTextCharFormat()
        cfOperator.setForeground(Qt.lightGray)
        cfBold = QTextCharFormat()
        cfBold.setFontWeight(QFont.Bold)
        cfItalic = QTextCharFormat()
        cfItalic.setFontItalic(True)

        # Titles (only atx-style, with #, not underlined)
        defaultSize = self._defaultCharFormat.font().pointSize()
        r = self.rules["Title"]
        for m in r.finditer(text):
            cfOperator.setFontPointSize(defaultSize + 12 - 2 * len(m.group(1)))
            cfBold.setFontPointSize(defaultSize + 12 - 2 * len(m.group(1)))

            self.setFormat(m.start(1), len(m.group(1)), cfOperator)
            self.setFormat(m.start(3), len(m.group(3)), cfBold)
            self.setFormat(m.start(4), len(m.group(4)), cfOperator)

        # Code blocks
        r = self.rules["Code"]
        format = QTextCharFormat()
        format.setForeground(Qt.darkGray)
        format.setFontFixedPitch(True)
        for m in r.finditer(text):
            self.setFormat(m.start(), m.end() - m.start(), format)

        # Basic stuff
        stuff = [
            ("Blockquotes", Qt.blue),
            ("OrderedList", Qt.red),
            ("UnorderedList", Qt.darkRed),
            ("HTML", Qt.darkGreen),
        ]
        for name, color in stuff:
            r = self.rules[name]
            format = QTextCharFormat()
            format.setForeground(color)
            for m in r.finditer(text):
                self.setFormat(m.start(), m.end() - m.start(), format)

        # Bold and Italic
        for name, style in [
            ("Italic", cfItalic),
            ("Italic2", cfItalic),
            ("Bold", cfBold),
            ("Bold2", cfBold),
        ]:
            r = self.rules[name]

            for m in r.finditer(text):
                self.setFormat(m.start(1), len(m.group(1)), cfOperator)
                self.setFormat(m.start(2), len(m.group(2)), style)
                self.setFormat(m.start(3), len(m.group(3)), cfOperator)

        # Links
        cfURL = QTextCharFormat()
        cfURL.setForeground(Qt.darkGreen)
        cfURL.setFontItalic(True)
        cfText = QTextCharFormat()
        cfText.setForeground(Qt.darkBlue)
        cfIdentifier = QTextCharFormat()
        cfIdentifier.setForeground(Qt.darkMagenta)

        for type in ['Links-inline', 'Links-ref']:
            r = self.rules[type]
            for m in r.finditer(text):
                self.setFormat(m.start(1), len(m.group(1)), cfOperator)
                self.setFormat(m.start(2), len(m.group(2)), cfText)
                self.setFormat(m.start(3), len(m.group(3)), cfOperator)
                self.setFormat(m.start(4), len(m.group(4)), cfOperator)
                self.setFormat(m.start(5), len(m.group(5)), cfURL if "inline" in type else cfIdentifier)
                self.setFormat(m.start(6), len(m.group(6)), cfOperator)

        r = self.rules["Links-ref2"]
        for m in r.finditer(text):
            self.setFormat(m.start(1), len(m.group(1)), cfOperator)
            self.setFormat(m.start(2), len(m.group(2)), cfIdentifier)
            self.setFormat(m.start(3), len(m.group(3)), cfOperator)
            self.setFormat(m.start(4), len(m.group(4)), cfURL)
            self.setFormat(m.start(5), len(m.group(5)), cfText)
